@@ -92,56 +92,60 @@ $(function(){
 	    var format = IsoplotR.settings["U-Pb"].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 7;
-	    case 3: return 10;
+	    case 2: return 8;
+	    case 3: return 11;
 	    case 4:
-	    case 5: return 11;
-	    case 6: return 14;
+	    case 5: return 12;
+	    case 6: return 15;
 	    case 7:
-	    case 8: return 16;
+	    case 8: return 17;
+	    case 9: return 8;
+	    case 10: return 8;
+	    case 11: return 12;
+	    case 12: return 12;
 	    }
 	case 'Pb-Pb':
 	    var format = IsoplotR.settings["Pb-Pb"].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 7;
-	    case 3: return 8;
+	    case 2: return 8;
+	    case 3: return 9;
 	    }
 	case 'Ar-Ar':
 	    var format = IsoplotR.settings["Ar-Ar"].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 8;
-	    case 3: return 9;
+	    case 2: return 9;
+	    case 3: return 10;
 	    }
 	case 'Th-Pb':
 	    var format = IsoplotR.settings["Th-Pb"].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 7;
-	    case 3: return 8;
+	    case 2: return 8;
+	    case 3: return 9;
 	    }
 	case 'K-Ca':
 	    var format = IsoplotR.settings["K-Ca"].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 7;
-	    case 3: return 8;
+	    case 2: return 8;
+	    case 3: return 9;
 	    }
 	case 'Th-U':
 	    var format = IsoplotR.settings["Th-U"].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 11;
+	    case 2: return 12;
 	    case 3:
-	    case 4: return 7;
+	    case 4: return 8;
 	    }
 	case 'fissiontracks':
 	    var format = IsoplotR.settings.fissiontracks.format;
 	    if (format<2){
-		return 4;
+		return 5;
 	    } else {
-		return 14;
+		return 15;
 	    }
 	case 'Rb-Sr':
 	case 'Sm-Nd':
@@ -150,11 +154,11 @@ $(function(){
 	    var format = IsoplotR.settings[gc].format;
 	    switch (format){
 	    case 1:
-	    case 2: return 7;
-	    case 3: return 8;
+	    case 2: return 8;
+	    case 3: return 9;
 	    }
 	case 'U-Th-He':
-	    return 10;
+	    return 11;
 	case 'detritals':
 	    var firstrow = $("#INPUT").handsontable('getData')[0];
 	    var nc = firstrow.length;
@@ -164,12 +168,12 @@ $(function(){
 	case 'other':
 	    var format = IsoplotR.settings[gc].format;
 	    switch (format){
-	    case 1: return 2;
-	    case 2: return 4;
-	    case 3: return 5;
-	    case 4: return 7;
-	    case 5: return 8;
-	    case 6: return countRows()+3;
+	    case 1: return 3;
+	    case 2: return 5;
+	    case 3: return 6;
+	    case 4: return 8;
+	    case 5: return 9;
+	    case 6: return countRows()+4;
 	    }
 	}
 	return 0;
@@ -286,7 +290,7 @@ $(function(){
 	    mydata.data = {}; // clear the object
 	    let nr = countRows();
 	    let ns = Math.round(nr/2);
-	    let H = new Array(nr+3);
+	    let H = new Array(nr+4);
 	    H[0] = '[X,Y]';
 	    mydata.data[0] = $("#INPUT").handsontable('getDataAtCol',0);
 	    for (let k=1; k<(ns+1); k++){
@@ -297,8 +301,10 @@ $(function(){
 	    }
 	    H[nr+1] = '(C)';
 	    H[nr+2] = '(omit)';
+	    H[nr+3] = '(comment)';
 	    mydata.data[nr+1] = $("#INPUT").handsontable('getDataAtCol',nr+1);
 	    mydata.data[nr+2] = $("#INPUT").handsontable('getDataAtCol',nr+2);
+	    mydata.data[nr+3] = $("#INPUT").handsontable('getDataAtCol',nr+3);
 	    let ht = $("#INPUT").handsontable('getInstance');
 	    ht.updateSettings({
 		colHeaders: H
@@ -407,7 +413,7 @@ $(function(){
 			row.push(0);
 		    } else if ((ArAr1 & j==5)|(ArAr2 & j==5)|(ArAr3 & j==6)) { // Ar39
 			row.push(1);
-		    } else if (omissable & j==(nc-1) & val!=null){ // omit
+		    } else if (omissable & j==(nc-2) & val!=null){ // omit
 			row.push(val);
 		    } else {
 			row.push('');
@@ -565,6 +571,22 @@ $(function(){
 		$(".show4UPb8").show();
 		$('.hide4UPb8').hide();
 		break;
+	    case 9:
+		$(".show4UPb9").show();
+		$('.hide4UPb9').hide();
+		break;
+	    case 10:
+		$(".show4UPb10").show();
+		$('.hide4UPb10').hide();
+		break;
+	    case 11:
+		$(".show4UPb11").show();
+		$('.hide4UPb11').hide();
+		break;
+	    case 12:
+		$(".show4UPb12").show();
+		$('.hide4UPb12').hide();
+		break;
 	    }
 	    switch (set.cutoffdisc){
 	    case 0:
@@ -608,7 +630,12 @@ $(function(){
 	    } else {
 		$(".show4diseq").hide();
 	    }
-	    if (set.commonPb!=1 & pd.anchor!=1){
+	    if (['concordia','isochron'].includes(plotdevice)){
+		noPb0anchor = pd.anchor[0]!=1
+	    } else {
+		noPb0anchor = true
+	    }
+	    if (set.commonPb!=1 & noPb0anchor){
 		$('.show4commonPbwithout204').hide();
 		$('.show4commonPbwith204').hide();
 		$('.show4commonPbwith208').hide();
@@ -616,11 +643,11 @@ $(function(){
 		$('.show4commonPbwithout204').show();
 		$('.show4commonPbwith204').hide();
 		$('.show4commonPbwith208').hide();
-	    } else if (set.format<7){
+	    } else if ([4,5,6,9,10].includes(set.format)){
 		$('.show4commonPbwithout204').hide();
 		$('.show4commonPbwith204').show();
 		$('.show4commonPbwith208').hide();
-	    } else {
+	    } else if ([7,8,11,12].includes(set.format)){
 		$('.show4commonPbwithout204').hide();
 		$('.show4commonPbwith204').hide();
 		$('.show4commonPbwith208').show();
@@ -915,7 +942,7 @@ $(function(){
 		$('.hide4model3').hide();
 		break;
 	    }
-	    if (pd.anchor == 2){
+	    if (pd.anchor[0] == 2) {
 		$('.show4tanchor').show();
 	    } else {
 		$('.show4tanchor').hide();
@@ -934,8 +961,19 @@ $(function(){
 	    break;
 	case 'isochron':
 	    $(".hide4isochron").hide();
-	    if (pd.anchor == 2){
+	    if (geochronometer!='U-Pb' && pd.anchor[0]==3){
+		pd.anchor[0]=0; // reset
+	    }
+	    if (pd.anchor[0]==1){
+		$('.show4ianchor').show();
+	    } else {
+		$('.show4ianchor').hide();
+	    }
+	    if (pd.anchor[0]==2){
 		$('.show4tanchor').show();
+	    } else if (pd.anchor[0]>0 & geochronometer=='U-Th-He'){
+		$('.show4tanchor').hide();
+		$('.show4HeAnchor').show();
 	    } else {
 		$('.show4tanchor').hide();
 	    }
@@ -953,8 +991,7 @@ $(function(){
 		    $('.show4UPby0option1').show();
 		    $('.hide4UPby0option1').hide();
 		}
-	    }
-	    if (geochronometer=='Th-U' & set.format<3){
+	    } else if (geochronometer=='Th-U' & set.format<3){
 		switch (pd.ThU_y0option){
 		case 1:
 		    $('.show4ThUy0option1').show();
@@ -970,6 +1007,16 @@ $(function(){
 		}
 	    }
 	case 'regression':
+	    if (['U-Pb','Th-U'].indexOf(geochronometer)<0 & pd.model==3 & pd.anchor[0]<1){
+		$('.show4wtype').show();
+	    } else {
+		$('.show4wtype').hide();
+	    }
+	    if (geochronometer=='other' & pd.anchor[0]>0){
+		$('.show4anchor').show();
+	    } else {
+		$('.show4anchor').hide();
+	    }
 	case 'helioplot':
 	    switch (pd.model){
 	    case 1:
@@ -1083,6 +1130,9 @@ $(function(){
 	setOption('#oerr',IsoplotR.settings.oerr);
 	$('#alpha').val(cst.alpha);
 	$('#sigdig').val(IsoplotR.settings.sigdig);
+	if (['ages','set-zeta'].indexOf(plotdevice)<0){
+	    $('#cex').val(IsoplotR.settings.par.cex);
+	}
 	switch (option){
 	case 'U-Pb':
 	    setOption('#UPb-formats',set.format);
@@ -1103,10 +1153,10 @@ $(function(){
 	    $('#errPb207Pb204').val(cst.iratio.Pb207Pb204[1]);
 	    $('#Pb207Pb206').val(cst.iratio.Pb207Pb206[0]);
 	    $('#errPb207Pb206').val(cst.iratio.Pb207Pb206[1]);
-	    $('#Pb208Pb206').val(cst.iratio.Pb208Pb206[0]);
-	    $('#errPb208Pb206').val(cst.iratio.Pb208Pb206[1]);
-	    $('#Pb208Pb207').val(cst.iratio.Pb208Pb207[0]);
-	    $('#errPb208Pb207').val(cst.iratio.Pb208Pb207[1]);
+	    $('#Pb206Pb208').val(cst.iratio.Pb206Pb208[0]);
+	    $('#errPb206Pb208').val(cst.iratio.Pb206Pb208[1]);
+	    $('#Pb207Pb208').val(cst.iratio.Pb207Pb208[0]);
+	    $('#errPb207Pb208').val(cst.iratio.Pb207Pb208[1]);
 	    $('#U238U235').val(cst.iratio.U238U235[0]);
 	    $('#LambdaU238').val(cst.lambda.U238[0]);
 	    $('#errLambdaU238').val(cst.lambda.U238[1]);
@@ -1331,7 +1381,7 @@ $(function(){
 	case 'concordia':
 	    setOption('#concordia-type',set.type);
 	    setOption('#conc-age-option',set.showage);
-	    setOption('#anchor-option',set.anchor);
+	    setOption('#anchor-option',set.anchor[0]);
 	    $('#mint').val(set.mint);
 	    $('#maxt').val(set.maxt);
 	    $('#minx').val(set.minx);
@@ -1347,22 +1397,25 @@ $(function(){
 	    $('#ellipsestroke').val(set.ellipsestroke);
 	    $('#clabel').val(set.clabel);
 	    $('#ticks').val(set.ticks);
-	    $('#cex').val(IsoplotR.settings.par.cex);
-	    $('#tanchor').val(set.tanchor[0]);
-	    $('#stanchor').val(set.tanchor[1]);
+	    $('#anchor').val(set.anchor[1]);
+	    $('#anchor-err').val(set.anchor[2]);
 	    break;
 	case 'isochron':
 	    setOption('#ThU-isochron-types',set.ThUtype);
 	    setOption('#UPb_y0option',set.UPb_y0option);
 	    setOption('#ThU_y0option',set.ThU_y0option);
 	    setOption('#UPb-isochron-types',set.UPbtype);
-	    setOption('#anchor-option',set.anchor);
+	    setOption('#anchor-option',set.anchor[0]);
 	    $('#isochron-exterr').prop('checked',set.exterr)
 	    $('#PbPb-growth').prop('checked',set.growth)
 	    $('#joint').prop('checked',set.joint)
-	    $('#tanchor').val(set.tanchor[0]);
-	    $('#stanchor').val(set.tanchor[1]);
+	    $('#anchor').val(set.anchor[1]);
+	    $('#anchor-err').val(set.anchor[2]);
 	case 'regression':
+	    $("#wtype").prop('checked',set.wtype==2);
+	    setOption('#regression-anchor-option',set.anchor[0]);
+	    $('#regression-anchor').val(set.anchor[1]);
+	    $('#regression-anchor-err').val(set.anchor[2]);
 	    $('#shownumbers').prop('checked',set.shownumbers);
 	    $('#isochron-minx').val(set.minx);
 	    $('#isochron-maxx').val(set.maxx);
@@ -1375,7 +1428,6 @@ $(function(){
 	    $('#ellipsefill_ramp_end').val(set.ellipsefill.ramp_end);
 	    $('#ellipsestroke').val(set.ellipsestroke);
 	    $('#clabel').val(set.clabel);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    break;
 	case 'radial':
 	    setOption('#transformation',set.transformation);
@@ -1391,9 +1443,8 @@ $(function(){
             setOption('#bg_option', set.bg.option);
             $('#bg_ramp_start').val(set.bg.ramp_start);
             $('#bg_ramp_end').val(set.bg.ramp_end);
-        $('#clabel').val(set.clabel);
+            $('#clabel').val(set.clabel);
 	    $('#pcex').val(set.cex);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    $('#exterr').prop('checked',set.exterr);
 	    break;
 	case 'average':
@@ -1403,7 +1454,6 @@ $(function(){
 	    $('#ranked').prop('checked',set.ranked);
 	    $('#mint').val(set.mint);
 	    $('#maxt').val(set.maxt);
-	    $('#cex').val(IsoplotR.settings.par.cex);
             setOption('#bg_option', set.bg.option);
             $('#bg_ramp_start').val(set.bg.ramp_start);
             $('#bg_ramp_end').val(set.bg.ramp_end);
@@ -1415,7 +1465,6 @@ $(function(){
 	    $('#exterr').prop('checked',set.exterr);
 	    $('#plateau').prop('checked',set.plateau);
 	    $('#randomeffects').prop('checked',set.randomeffects);
-	    $('#cex').val(IsoplotR.settings.par.cex);
             setOption('#bg_option',set.bg.option);
 	    $('#bg_ramp_start').val(set.bg.ramp_start);
 	    $('#bg_ramp_end').val(set.bg.ramp_end);
@@ -1435,13 +1484,11 @@ $(function(){
 	    $('#binwidth').val(set.binwidth);
 	    $('#rugdetritals').prop('checked',set.rugdetritals);
 	    $('#rug').prop('checked',set.rug);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    setOption('#nmodes', set.nmodes);
 	    break;
 	case 'CAD':
 	    $('#verticals').prop('checked',set.verticals);
 	    $('#pch').val(set.pch);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    setOption('#colmap_option',set.colmap);
             copy_background('colmap_option');
 	    break;
@@ -1467,9 +1514,8 @@ $(function(){
 	    $('#pch').val(set.pch);
 	    $('#pos').val(set.pos);
 	    $('#col').val(set.col);
-        $('#bg_solid').val(set.bg);
+            $('#bg_solid').val(set.bg);
 	    $('#pcex').val(set.cex);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    break;
 	case 'helioplot':
 	    $('#logratio').prop('checked',set.logratio);
@@ -1487,7 +1533,6 @@ $(function(){
 	    $('#ellipsestroke').val(set.ellipsestroke);
 	    setOption('#helioplot-models',set.model);
 	    $('#clabel').val(set.clabel);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    break;
 	case 'evolution':
 	    if (set.isochron){ $('.show4evolutionIsochron').show(); }
@@ -1509,7 +1554,6 @@ $(function(){
 	    $('#ellipsestroke').val(set.ellipsestroke);
 	    setOption('#evolution-isochron-models',set.model);
 	    $('#clabel').val(set.clabel);
-	    $('#cex').val(IsoplotR.settings.par.cex);
 	    break;
 	default:
 	}
@@ -1561,11 +1605,11 @@ $(function(){
 	    gcsettings.RaU[1] = getNumber('#sRaU');
 	    gcsettings.PaU[1] = getNumber('#sPaU');
 	    cst.iratio.Pb207Pb206[0] = getNumber('#Pb207Pb206');
-	    cst.iratio.Pb208Pb206[0] = getNumber('#Pb208Pb206');
-	    cst.iratio.Pb208Pb207[0] = getNumber('#Pb208Pb207');
+	    cst.iratio.Pb206Pb208[0] = getNumber('#Pb206Pb208');
+	    cst.iratio.Pb207Pb208[0] = getNumber('#Pb207Pb208');
 	    cst.iratio.Pb207Pb206[1] = getNumber('#errPb207Pb206');
-	    cst.iratio.Pb208Pb206[1] = getNumber('#errPb208Pb206');
-	    cst.iratio.Pb208Pb207[1] = getNumber('#errPb208Pb207');
+	    cst.iratio.Pb206Pb208[1] = getNumber('#errPb206Pb208');
+	    cst.iratio.Pb207Pb208[1] = getNumber('#errPb207Pb208');
 	    cst.lambda.Th232[0] = getNumber("#LambdaTh232");
 	    cst.lambda.Th232[1] = getNumber("#errLambdaTh232");
 	    cst.lambda.U234[0] = getNumber("#LambdaU234");
@@ -1737,6 +1781,9 @@ $(function(){
 	    break;
 	default:
 	}
+	if (['ages','set-zeta'].indexOf(plotdevice)<0){
+	    IsoplotR.settings.par.cex = getNumber('#cex');
+	}
 	switch (plotdevice){
 	case 'concordia':
 	    pdsettings.type = getOption('#concordia-type');
@@ -1758,25 +1805,30 @@ $(function(){
 	    pdsettings.ellipsestroke = $('#ellipsestroke').val();
 	    pdsettings.clabel = $('#clabel').val();
 	    pdsettings.ticks = $('#ticks').val();
-	    pdsettings.anchor = getOption("#anchor-option")
-	    pdsettings.tanchor[0] = getNumber('#tanchor');
-	    pdsettings.tanchor[1] = getNumber('#stanchor');
-	    IsoplotR.settings.par.cex = getNumber('#cex');
+	    pdsettings.anchor[0] = getOption("#anchor-option")
+	    pdsettings.anchor[1] = getNumber('#anchor');
+	    pdsettings.anchor[2] = getNumber('#anchor-err');
 	    break;
 	case 'isochron':
 	    pdsettings.UPbtype = getOption("#UPb-isochron-types");
 	    pdsettings.ThUtype = getOption("#ThU-isochron-types");
 	    pdsettings.UPb_y0option = getOption("#UPb_y0option");
 	    pdsettings.ThU_y0option = getOption("#ThU_y0option");
-	    pdsettings.anchor = getOption("#anchor-option")
-	    pdsettings.tanchor[0] = getNumber('#tanchor');
-	    pdsettings.tanchor[1] = getNumber('#stanchor');
+	    pdsettings.anchor[0] = getOption("#anchor-option")
+	    pdsettings.anchor[1] = getNumber('#anchor');
+	    pdsettings.anchor[2] = getNumber('#anchor-err');
 	    pdsettings.exterr = truefalse('#isochron-exterr');
 	    pdsettings.growth = truefalse('#PbPb-growth');
 	    pdsettings.joint = truefalse('#joint');
 	    pdsettings.model = getOption("#isochron-models");
 	    inverse(geochronometer);
 	case 'regression':
+	    pdsettings.wtype = truefalse('#wtype') ? 2 : 1;
+	    if (geochronometer=='other'){
+		pdsettings.anchor[0] = getOption("#regression-anchor-option");
+		pdsettings.anchor[1] = getNumber('#regression-anchor');
+		pdsettings.anchor[2] = getNumber('#regression-anchor-err');
+	    }
 	    pdsettings.shownumbers = truefalse('#shownumbers');
 	    pdsettings.model = getOption("#isochron-models");
 	    pdsettings.minx = check($('#isochron-minx').val(),'auto');
@@ -1791,7 +1843,6 @@ $(function(){
             };
 	    pdsettings.ellipsestroke = $('#ellipsestroke').val();
 	    pdsettings.clabel = $('#clabel').val();
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    break;
 	case 'radial':
 	    pdsettings.shownumbers = truefalse('#shownumbers');
@@ -1810,7 +1861,6 @@ $(function(){
 	    pdsettings.clabel = $('#clabel').val();
 	    pdsettings["cex"] = getNumber('#pcex');
 	    pdsettings.exterr = truefalse('#exterr');
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    i2i(geochronometer);
 	    break;
 	case 'average':
@@ -1828,7 +1878,6 @@ $(function(){
 	    pdsettings.outliercol = $('#outliercol').val();
             pdsettings.rect_alpha = getNumber('#rect_alpha', 1);
 	    pdsettings.clabel = $('#clabel').val();
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    i2i(geochronometer);
 	    break;
 	case 'spectrum':
@@ -1843,7 +1892,6 @@ $(function(){
 	    pdsettings.nonplateaucol = $('#nonplateaucol').val();
             pdsettings.nonplateau_alpha = getNumber('#nonplateau_alpha', 1);
 	    pdsettings.clabel = $('#clabel').val();
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    i2i(geochronometer);
 	    break;
 	case 'KDE':
@@ -1859,14 +1907,12 @@ $(function(){
 	    pdsettings.rugdetritals = truefalse('#rugdetritals');
 	    pdsettings.rug = truefalse('#rug');
 	    pdsettings.nmodes = getOption("#nmodes");
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    i2i(geochronometer);
 	    break;
 	case 'CAD':
 	    pdsettings.pch = $('#pch').val();
 	    pdsettings.colmap = getOption('#colmap_option');
 	    pdsettings.verticals = truefalse('#verticals');
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    i2i(geochronometer);
 	    break;
 	case 'set-zeta':
@@ -1887,7 +1933,6 @@ $(function(){
 	    pdsettings.col = $('#col').val();
             pdsettings.bg = $('#bg_solid').val();
 	    pdsettings.cex = getNumber('#pcex');
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    break;
 	case 'ages':
 	    if (geochronometer == 'U-Pb'){
@@ -1921,7 +1966,6 @@ $(function(){
 	    pdsettings.ellipsestroke = $('#ellipsestroke').val();
 	    pdsettings.model = getOption("#helioplot-models");
 	    pdsettings.clabel = $('#clabel').val();
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    break;
 	case 'evolution':
 	    pdsettings.transform = truefalse('#transform-evolution');
@@ -1943,7 +1987,6 @@ $(function(){
 	    pdsettings.ellipsestroke = $('#ellipsestroke').val();
 	    pdsettings.model = getOption("#evolution-isochron-models");
 	    pdsettings.clabel = $('#clabel').val();
-	    IsoplotR.settings.par.cex = getNumber('#cex');
 	    break;
 	default:
 	}
@@ -2067,8 +2110,10 @@ $(function(){
 	$("#spotSizeDiv").hide();
 	switch (geochronometer){
 	case 'U-Pb':
-	    setSelectedMenus(['concordia','isochron','radial',
-			      'average','KDE','CAD','ages'],open);
+	    let menus = IsoplotR.settings['U-Pb'].format<9 ?
+		['concordia','isochron','radial','average','KDE','CAD','ages'] :
+		['isochron','radial','average','KDE','CAD','ages'] ;
+	    setSelectedMenus(menus,open);
 	    break;
 	case 'Ar-Ar':
 	    setSelectedMenus(['isochron','radial','spectrum',
@@ -2092,7 +2137,7 @@ $(function(){
 			      'KDE','CAD','ages'],open);
 	    break;
 	case 'fissiontracks':
-	    var format = IsoplotR.settings.fissiontracks.format;
+	    let format = IsoplotR.settings.fissiontracks.format;
 	    setSelectedMenus(['radial','average','KDE',
 			      'CAD','set-zeta','ages'],open);
 	    if (format < 3){ $("#zetaDiv").show(); }
@@ -2257,6 +2302,8 @@ $(function(){
 	var UPb345 = (gc=='U-Pb' && ($.inArray(format,[3,4,5])>-1));
 	var UPb6 = (gc=='U-Pb' && format==6);
 	var UPb78 = (gc=='U-Pb' && ($.inArray(format,[7,8])>-1));
+	var UPb910 = (gc=='U-Pb' && ($.inArray(format,[9,10])>-1));
+	var UPb1112 = (gc=='U-Pb' && ($.inArray(format,[11,12])>-1));
 	var PbPb12 = (gc=='Pb-Pb' && ($.inArray(format,[1,2])>-1));
 	var PbPb3 = (gc=='Pb-Pb' && format==3);
 	var ArAr12 = (gc=='Ar-Ar' && ($.inArray(format,[1,2])>-1));
@@ -2282,13 +2329,13 @@ $(function(){
 	var regression5 = (gc=='other' && pd=='regression' && format==5);
 	var spectrum = (gc=='other' && pd=='spectrum');
 	var average = (gc=='other' && pd=='average');
-	if (UPb12 || PbPb12 || ArAr12 || ThPb12 ||
-	    KCa12 || RbSr12 || SmNd12 || ReOs12 ||
-	    LuHf12 || ThU34 || regression4){
+	if (UPb12  || UPb910 || PbPb12 || ArAr12 ||
+	    ThPb12 || KCa12  || RbSr12 || SmNd12 ||
+	    ReOs12 || LuHf12 || ThU34  || regression4){
 	    cols = [1,3];
-	} else if (UPb345 || PbPb3 || ArAr3 || ThPb3 ||
-		   KCa3 || RbSr3 || SmNd3 || ReOs3 ||
-		   LuHf3 || UThHe || ThU12 || regression5){
+	} else if (UPb345 || UPb1112 || PbPb3 || ArAr3 ||
+		   ThPb3  || KCa3    || RbSr3 || SmNd3 ||
+		   ReOs3  || LuHf3   || UThHe || ThU12 || regression5){
 	    cols = [1,3,5];
 	} else if (UPb78){
 	    cols = [1,3,5,7];
@@ -2474,23 +2521,29 @@ $(function(){
     }
 
     $.chooseUPbFormat = function(){
-	var oldformat = IsoplotR.settings["U-Pb"].format;
-	var newformat = getInt('#UPb-formats');
-	var upgrade = (oldformat<4 & newformat>3);
-	var downgrade = (oldformat>3 & newformat<4);
-	var pd = IsoplotR.settings.plotdevice;
-	if (pd=='concordia'){
-	    IsoplotR.settings.concordia.type = getOption('#concordia-type');
-	    if (newformat<7 & IsoplotR.settings.concordia.type==3){
-		IsoplotR.settings.concordia.type = 2;
-		setOption("#concordia-type",2);
-	    }
+	let set = IsoplotR.settings["U-Pb"];
+	let oldformat = set.format;
+	let newformat = getInt('#UPb-formats');
+	let D3D2 = oldformat<9 & newformat>8;
+	let D2D3 = oldformat>8 & newformat<9;
+	let pd = IsoplotR.settings.plotdevice;
+	if (D3D2){
+	    if (pd=='concordia'){ pd = 'isochron'; }
+	    set.cutoffdisc = 0;
+	    set.type = [10,12].includes(newformat) ? 1 : 2;
+	}
+	if (pd=='concordia' & newformat<7 & getOption('#concordia-type')==3){
+	    IsoplotR.settings.concordia.type = 2;
+	    setOption("#concordia-type",2);
 	}
 	$.chooseFormat('#UPb-formats',"U-Pb");
+	if (D3D2 | D2D3){
+	    changePlotDevice();
+	    selectGeochronometer();
+	}
 	showSettings(pd);
-	if (IsoplotR.settings["U-Pb"].ThU[1]==3 &
-	    IsoplotR.settings["U-Pb"].format<7){
-	    IsoplotR.settings["U-Pb"].ThU[1] = 0;
+	if (set.ThU[1]==3 & set.format<7){
+	    set.ThU[1] = 0;
 	}
     }
 
@@ -2532,14 +2585,14 @@ $(function(){
 	errconvert();
 	showOrHide();
     }
-
+    
     $.chooseDiscFilter = function(){
 	var opt = getOption("#discoption");
 	var set = IsoplotR.settings['U-Pb'];
 	set.discoption = opt;
 	$('#mindisc').val(set.mindisc[opt-1]);
 	$('#maxdisc').val(set.maxdisc[opt-1]);
-    }    
+    }
     
     $.chooseMineral = function(){
 	var cst = IsoplotR.constants;
