@@ -14,7 +14,7 @@ function example(geochronometer,plotdevice,format){
 			       0.03971,0.03967,0.03966,0.03974,0.03607],
 		    "err[Y]": [0.00004,0.00004,0.0001,0.00005,0.00004,
 			       0.0001,0.00004,0.00006,0.00004,0.00005],
-		    "rho":    [0.79,0.31,0.85,0.58,0.65,0.88,0.43,0.74,0.65,0.87],
+		    "rXY":    [0.79,0.31,0.85,0.58,0.65,0.88,0.43,0.74,0.65,0.87],
 		    "(C)":    [],
 		    "(omit)": [],
 		    "(comment)": []
@@ -32,7 +32,7 @@ function example(geochronometer,plotdevice,format){
 			       0.05134,0.05143,0.05139,0.0514,0.05135],
 		    "err[Y]": [0.00004,0.00016,0.00008,0.00009,0.00006,
 			       0.00007,0.00011,0.00007,0.00006,0.00004],
-		    "(rho)":  [],
+		    "(rXY)":  [],
 		    "(C)":    [],
 		    "(omit)": [],
 		    "(comment)": []
@@ -54,8 +54,8 @@ function example(geochronometer,plotdevice,format){
 				  0.05134,0.05143,0.05139,0.0514,0.05135],
 		    "err[Z]":  [0.00004,0.00016,0.00008,0.00009,0.00006,
 				0.00007,0.00011,0.00007,0.00006,0.00004],
-		    "(rhoXY)": [],
-		    "(rhoYZ)": [],
+		    "(rXY)": [],
+		    "(rYZ)": [],
 		    "(C)":     [],
 		    "(omit)":  [],
 		    "(comment)": []
@@ -73,9 +73,9 @@ function example(geochronometer,plotdevice,format){
 				 0.0008678,0.0018790,0.0007820],
 		    "err[Z]":  [0.0000020,0.0000018,0.0000016,0.0000022,
 			        0.0000018,0.0000024,0.0000020],
-		    "rhoXY":   [0.90,0.89,0.82,0.90,0.93,0.84,0.79],
-		    "rhoXZ":   [0.59,0.56,0.32,0.55,0.78,0.39,0.40],
-		    "rhoYZ":   [0.82,0.82,0.69,0.79,0.93,0.74,0.79],
+		    "rXY":   [0.90,0.89,0.82,0.90,0.93,0.84,0.79],
+		    "rXZ":   [0.59,0.56,0.32,0.55,0.78,0.39,0.40],
+		    "rYZ":   [0.82,0.82,0.69,0.79,0.93,0.74,0.79],
 		    "(C)":     [],
 		    "(omit)":  [],
 		    "(comment)": []
@@ -91,9 +91,9 @@ function example(geochronometer,plotdevice,format){
 		    "err[Y]":  [0.00020,0.00020,0.00023,0.00023,0.00019,0.00023,0.00035],
 		    "Z=04/06": [0.016331,0.015486,0.012047,0.01517,0.013388,0.022121,0.012372],
 		    "err[Z]":  [0.000016,0.000015,0.000018,0.00002,0.00001,0.000019,0.000019],
-		    "rhoXY":   [0,0,0,0,0,0,0],
-		    "rhoXZ":   [0,0,0,0,0,0,0],
-		    "rhoYZ":   [-0.6,-0.6,-0.6,-0.6,-0.6,-0.6,-0.6],
+		    "rXY":   [0,0,0,0,0,0,0],
+		    "rXZ":   [0,0,0,0,0,0,0],
+		    "rYZ":   [-0.6,-0.6,-0.6,-0.6,-0.6,-0.6,-0.6],
 		    "(C)":     [],
 		    "(omit)":  [],
 		    "(comment)": []
@@ -147,15 +147,15 @@ function example(geochronometer,plotdevice,format){
 		    "Z=32/38":  [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
 				 17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
 		    "(err[Z])": [],
-		    "(rhoWX)":  [0.62,0.63,0.81,0.79,0.39,0.65,0.62,0.63,0.58,0.6,
+		    "(rWX)":  [0.62,0.63,0.81,0.79,0.39,0.65,0.62,0.63,0.58,0.6,
 				 0.6,0.27,0.89,0.66,0.69,0.64,0.63,0.53,0.38,0.6],
-		    "(rhoWY)":  [0.44,0.45,0.57,0.56,0.28,0.46,0.44,0.45,0.41,0.42,
+		    "(rWY)":  [0.44,0.45,0.57,0.56,0.28,0.46,0.44,0.45,0.41,0.42,
 				 0.43,0.19,0.63,0.47,0.49,0.46,0.44,0.38,0.27,0.42],
-		    "(rhoWZ)":  [],
-		    "(rhoXY)":  [0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,
+		    "(rWZ)":  [],
+		    "(rXY)":  [0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,0.71,
 				 0.71,0.71,0.71,0.71,0.71,0.71,0.7,0.71,0.71,0.7],
-		    "(rhoXZ)":  [],
-		    "(rhoYZ)":  [],
+		    "(rXZ)":  [],
+		    "(rYZ)":  [],
 		    "(C)":      [],
 		    "(omit)":   [],
 		    "(comment)":[]
@@ -177,18 +177,86 @@ function example(geochronometer,plotdevice,format){
 				 1.66,4.26,3.06,2.36,8.33,2.1,2.14,2.25,2.4,2.34],
 		    "err[Y]":   [0.067,0.071,0.118,0.108,0.071,0.064,0.063,0.08,0.123,0.109,
 			 	 0.076,0.183,0.165,0.073,0.5,0.065,0.043,0.108,0.07,0.073],
-		    "Z=32/38":  [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
-				 17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
+		    "(Z=32/38)": [4.44,5.3,4.19,1.25,1.75,6.43,3.15,1.68,14.97,10.77,2.34,
+				  17.32,26.71,16.04,50.7,5.09,10.51,7.21,10.02,12.24],
 		    "(err[Z])": [],
-		    "(rhoWX)":  [],
-		    "(rhoWY)":  [],
-		    "(rhoWZ)":  [],
-		    "(rhoXY)":  [],
-		    "(rhoXZ)":  [],
-		    "(rhoYZ)":  [],
+		    "(rWX)":  [],
+		    "(rWY)":  [],
+		    "(rWZ)":  [],
+		    "(rXY)":  [],
+		    "(rXZ)":  [],
+		    "(rYZ)":  [],
 		    "(C)":      [],
 		    "(omit)":   [],
-		    "(comment)":[]
+		    "(comment)": []
+		}
+	    });
+	case 9:
+	    return({
+		"ierr": 1,
+		"data": {
+		    "X=38/06": [14.24,14.575,16.045,14.695,15.428,11.773,15.821],
+		    "err[X]":  [0.02,0.02,0.023,0.025,0.029,0.011,0.031],
+		    "Y=04/06": [0.016331,0.015486,0.012047,0.01517,0.013388,0.022121,0.012372],
+		    "err[Y]":  [0.000016,0.000015,0.000018,0.00002,0.00001,0.000019,0.000019],
+		    "(rXY)": [],
+		    "(C)":     [],
+		    "(omit)":  [],
+		    "(comment)": []
+		}
+	    });
+	case 10:
+	    return({
+		"ierr": 1,
+		"data": {
+		    "X=35/07": [0.354246,0.378774,0.509606,0.387027,0.450288,0.227335,0.491981],
+		    "err[X]":  [0.000552,0.000588,0.000883,0.000734,0.000912,0.000253,0.00121],
+		    "Y=04/07": [0.055988,0.055464,0.052731,0.055062,0.053854,0.058871,0.053023],
+		    "err[Y]":  [0.000084,0.000085,0.00012,0.000106,0.000073,0.000078,0.000142],
+		    "(rXY)": [0.35,0.4,0.46,0.38,0.3,0.46,0.56],
+		    "(C)":     [],
+		    "(omit)":  [],
+		    "(comment)": []
+		}
+	    });
+	case 11:
+	    return({
+		"ierr": 1,
+		"data": {
+		    "X=38/06": [406.2,404.8,399.1,678,666,656,664,504,521.9,695.3,665.5,652],
+		    "err[X]":  [11.2,9.05,9.6,18,15,14,11,15,9.45,6.1,8.75,16],
+		    "Y=08/06": [0.979,0.991,0.994,0.0765,0.072,0.0705,
+				0.071,0.612,0.601,0.03336,0.03525,0.0548],
+		    "err[Y]":  [0.0175,0.0205,0.0255,0.0042,0.00225,0.0018,
+				0.00125,0.014,0.017,0.00102,0.00067,0.0017],
+		    "(Z=32/38)": [],
+		    "(err[Z])":  [],
+		    "(rXY)":   [0.07,-0.05,-0.05,0.02,0.04,-0.14,0.01,-0.55,0.31,-0.35,-0.13,-0.06],
+		    "(rXZ)":   [],
+		    "(rYZ)":   [],
+		    "(C)":     [],
+		    "(omit)":  [],
+		    "(comment)": []
+		}
+	    });
+	case 12:
+	    return({
+		"ierr": 1,
+		"data": {
+		    "X=35/07": [14.56,24.2,25.19,27.1,26.6,109.7,112.1,116.5,122,143.6,144.9],
+		    "err[X]":  [0.625,0.73,0.77,1.2,1.2,2.45,3.3,3.7,3.65,2.25,3.95],
+		    "Y=08/07": [2.181,2.14,2.146,2.12,1.991,0.909,
+				0.913,0.743,0.748,0.3577,0.373],
+		    "err[Y]":  [0.0925,0.1295,0.0945,0.135,0.11,0.032,
+				0.0375,0.0325,0.0315,0.0085,0.013],
+		    "(Z=32/38)": [],
+		    "(err[Z])":  [],
+		    "(rXY)":   [0.83,0.62,0.33,0.75,0.87,0.84,0.79,0.84,0.78,0.69,0.82],
+		    "(rXZ)":   [],
+		    "(rYZ)":   [],
+		    "(C)":     [],
+		    "(omit)":  [],
+		    "(comment)": []
 		}
 	    });
 	}
